@@ -12,10 +12,14 @@ from .docking import *
 from .electronic_properties import *
 from .fukui import *
 from .hydrogen_bond_basicity import *
+from .ion_mobility import *
 from .irc import *
+from .macropka import *
 from .molecular_dynamics import *
 from .multistage_opt import *
 from .pka import *
+from .pose_analysis_md import *
+from .protein_cofolding import *
 from .redox_potential import *
 from .scan import *
 from .solubility import *
@@ -34,10 +38,14 @@ WORKFLOW_NAME = Literal[
     "electronic_properties",
     "fukui",
     "hydrogen_bond_basicity",
+    "ion_mobility",
     "irc",
+    "macropka",
     "molecular_dynamics",
     "multistage_opt",
     "pka",
+    "pose_analysis_md",
+    "protein_cofolding",
     "redox_potential",
     "scan",
     "solubility",
@@ -56,10 +64,14 @@ WORKFLOW_MAPPING: dict[WORKFLOW_NAME, Workflow] = {
     "electronic_properties": ElectronicPropertiesWorkflow,  # type: ignore [dict-item]
     "fukui": FukuiIndexWorkflow,  # type: ignore [dict-item]
     "hydrogen_bond_basicity": HydrogenBondBasicityWorkflow,  # type: ignore [dict-item]
+    "ion_mobility": IonMobilityWorkflow,  # type: ignore [dict-item]
     "irc": IRCWorkflow,  # type: ignore [dict-item]
+    "macropka": MacropKaWorkflow,  # type: ignore [dict-item]
     "molecular_dynamics": MolecularDynamicsWorkflow,  # type: ignore [dict-item]
     "multistage_opt": MultiStageOptWorkflow,  # type: ignore [dict-item]
     "pka": pKaWorkflow,  # type: ignore [dict-item]
+    "pose_analysis_md": PoseAnalysisMolecularDynamicsWorkflow,  # type: ignore [dict-item]
+    "protein_cofolding": ProteinCofoldingWorkflow,  # type: ignore [dict-item]
     "redox_potential": RedoxPotentialWorkflow,  # type: ignore [dict-item]
     "scan": ScanWorkflow,  # type: ignore [dict-item]
     "solubility": SolubilityWorkflow,  # type: ignore [dict-item]
