@@ -7,10 +7,10 @@ from .workflow import MoleculeWorkflow
 
 class HydrogenBondAcceptorSite(Base):
     """
-    A hydrogen bond acceptor site.
+    A hydrogen-bond-acceptor site.
 
     :param atom_idx: index of the atom
-    :param pkbhx: Hydrogen bond basicity
+    :param pkbhx: Hydrogen-bond basicity
     :param position: position of the atom
     :param name: name of the atom
     """
@@ -21,9 +21,23 @@ class HydrogenBondAcceptorSite(Base):
     name: str | None = None
 
 
+class HydrogenBondDonorSite(Base):
+    """
+    A hydrogen-bond-donor site.
+
+    :param atom_idx: index of the atom
+    :param pk_alpha: Hydrogen-bond acidity
+    :param position: position of the atom
+    """
+
+    atom_idx: int  # zero-indexed
+    pk_alpha: float
+    position: tuple[float, float, float]
+
+
 class HydrogenBondBasicityWorkflow(MoleculeWorkflow):
     """
-    Workflow for calculating hydrogen bond basicity.
+    Workflow for calculating hydrogen-bond basicity and acidity.
 
     Inherited:
     :param initial_molecule: Molecule of interest
@@ -36,6 +50,7 @@ class HydrogenBondBasicityWorkflow(MoleculeWorkflow):
     Results:
     :param optimization: UUID of optimization
     :param hba_sites: hydrogen-bond-acceptor sites
+    :param hbd_sites: hydrogen-bond-donor sites
     """
 
     do_csearch: bool = True
@@ -43,3 +58,4 @@ class HydrogenBondBasicityWorkflow(MoleculeWorkflow):
 
     optimization: UUID | None = None
     hba_sites: list[HydrogenBondAcceptorSite] = []  # noqa: RUF012
+    hbd_sites: list[HydrogenBondDonorSite] = []  # noqa: RUF012
